/**
 * @file highcharttable.js
 * 
 * Takes parameters set on the HighchartTable configuration page and invokes
 * HighchartTable chart-from-table function.
 *
 * @todo add I18n and refactor this rather messy code
 */
(function ($) {

  Drupal.behaviors.highcharttable = {

    attach: function(context, settings) {

      $(settings.highcharttable, context).each(function() {

        // settings.highcharttable is an array of params indexed by selectors as
        // entered on the HighchartTable config page. 1 selector per decoration.
        // In addition global config params are kept under 'global'.
        var baseLink = null;
        var linkStyle = null;
        $.each(this, function(selector, params) {

          if (selector === 'global') {
            linkStyle = params['contextual-links'];
            if (linkStyle !== 'off') {
              baseLink = params['contextual-links-callback'];
              var linkHtml = Drupal.behaviors.highcharttable.insertContextLinkHtml(baseLink, linkStyle);
              $(linkHtml).insertBefore('table');
            }
          }
          else {
            // table selector
            var decoratedTables = $(selector);
            if (decoratedTables.length > 0) {
              // Set all params on the special "data-graph-..." attributes.
              for (var dataKey in params) {
                if (dataKey !== 'hide-table' && params[dataKey] !== null) {
                  decoratedTables.attr('data-graph-' + dataKey, params[dataKey]);
                }
              }
              // Remove insert link before adding other links and the chart.
              decoratedTables.prev('.highcharttable-region').remove();

              if (baseLink && linkStyle !== 'off') {
                var linkHtml = Drupal.behaviors.highcharttable.configureDeleteContextLinksHtml(baseLink, linkStyle);
                $(linkHtml).insertBefore(decoratedTables);
              }

              decoratedTables.highchartTable();

              if (params['hide-table']) {
                decoratedTables.hide();
              }
            }
          }
        });
      });
    },

    insertContextLinkHtml: function(baseLink, linkStyle) {
      if (linkStyle === 'plain') {
        return '<div class="highcharttable-region">' +
              '<ul>' +
                '<li><a class="highcharttable-insert" href="' + baseLink + '/insert">Insert chart from table</a></li>' +
              '</ul>' +
            '</div>';
      }
      return '<div class="highcharttable-region contextual-links-region">' +
          '<div class="contextual-links-wrapper">' +
            '<ul class="contextual-links">' +
              '<li><a class="highcharttable-insert" href="' + baseLink + '/insert">Insert chart from table</a></li>' +
            '</ul>' +
          '</div>' +
        '</div>';
    },

    configureDeleteContextLinksHtml: function(baseLink, linkStyle) {
      if (linkStyle === 'plain') {
        return '<div class="highcharttable-region">' +
              '<ul>' +
                '<li><a class="highcharttable-configure" href="' + baseLink + '/configure">Configure this chart</a></li>' +
                '<li><a class="highcharttable-delete" href="' + baseLink + '/delete">Delete chart(s) from page</a></li>' +
              '</ul>' +
            '</div>';
      }
      return '<div class="highcharttable-region contextual-links-region">' +
          '<div class="contextual-links-wrapper">' +
            '<ul class="contextual-links">' +
              '<li><a class="highcharttable-configure" href="' + baseLink + '/configure">Configure this chart</a></li>' +
              '<li><a class="highcharttable-delete" href="' + baseLink + '/delete">Delete chart(s) from page</a></li>' +
            '</ul>' +
          '</div>' +
        '</div>';
    },
  };

}) (jQuery);


units = {
  percentCallback: function (value) {
    return value + '%';
  }
}
